'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES3 import _types as _cs
# End users want this...
from OpenGL.raw.GLES3._types import *
from OpenGL.raw.GLES3 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES3_VERSION_GLES3_3_1'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES3,'GLES3_VERSION_GLES3_3_1',error_checker=_errors._error_checker)
GL_ACTIVE_ATOMIC_COUNTER_BUFFERS=_C('GL_ACTIVE_ATOMIC_COUNTER_BUFFERS',0x92D9)
GL_ACTIVE_PROGRAM=_C('GL_ACTIVE_PROGRAM',0x8259)
GL_ACTIVE_RESOURCES=_C('GL_ACTIVE_RESOURCES',0x92F5)
GL_ACTIVE_VARIABLES=_C('GL_ACTIVE_VARIABLES',0x9305)
GL_ALL_BARRIER_BITS=_C('GL_ALL_BARRIER_BITS',0xFFFFFFFF)
GL_ALL_SHADER_BITS=_C('GL_ALL_SHADER_BITS',0xFFFFFFFF)
GL_ARRAY_SIZE=_C('GL_ARRAY_SIZE',0x92FB)
GL_ARRAY_STRIDE=_C('GL_ARRAY_STRIDE',0x92FE)
GL_ATOMIC_COUNTER_BARRIER_BIT=_C('GL_ATOMIC_COUNTER_BARRIER_BIT',0x00001000)
GL_ATOMIC_COUNTER_BUFFER=_C('GL_ATOMIC_COUNTER_BUFFER',0x92C0)
GL_ATOMIC_COUNTER_BUFFER=_C('GL_ATOMIC_COUNTER_BUFFER',0x92C0)
GL_ATOMIC_COUNTER_BUFFER_BINDING=_C('GL_ATOMIC_COUNTER_BUFFER_BINDING',0x92C1)
GL_ATOMIC_COUNTER_BUFFER_INDEX=_C('GL_ATOMIC_COUNTER_BUFFER_INDEX',0x9301)
GL_ATOMIC_COUNTER_BUFFER_SIZE=_C('GL_ATOMIC_COUNTER_BUFFER_SIZE',0x92C3)
GL_ATOMIC_COUNTER_BUFFER_START=_C('GL_ATOMIC_COUNTER_BUFFER_START',0x92C2)
GL_BLOCK_INDEX=_C('GL_BLOCK_INDEX',0x92FD)
GL_BUFFER_BINDING=_C('GL_BUFFER_BINDING',0x9302)
GL_BUFFER_DATA_SIZE=_C('GL_BUFFER_DATA_SIZE',0x9303)
GL_BUFFER_UPDATE_BARRIER_BIT=_C('GL_BUFFER_UPDATE_BARRIER_BIT',0x00000200)
GL_BUFFER_VARIABLE=_C('GL_BUFFER_VARIABLE',0x92E5)
GL_COMMAND_BARRIER_BIT=_C('GL_COMMAND_BARRIER_BIT',0x00000040)
GL_COMPUTE_SHADER=_C('GL_COMPUTE_SHADER',0x91B9)
GL_COMPUTE_SHADER_BIT=_C('GL_COMPUTE_SHADER_BIT',0x00000020)
GL_COMPUTE_WORK_GROUP_SIZE=_C('GL_COMPUTE_WORK_GROUP_SIZE',0x8267)
GL_DEPTH_STENCIL_TEXTURE_MODE=_C('GL_DEPTH_STENCIL_TEXTURE_MODE',0x90EA)
GL_DISPATCH_INDIRECT_BUFFER=_C('GL_DISPATCH_INDIRECT_BUFFER',0x90EE)
GL_DISPATCH_INDIRECT_BUFFER_BINDING=_C('GL_DISPATCH_INDIRECT_BUFFER_BINDING',0x90EF)
GL_DRAW_INDIRECT_BUFFER=_C('GL_DRAW_INDIRECT_BUFFER',0x8F3F)
GL_DRAW_INDIRECT_BUFFER_BINDING=_C('GL_DRAW_INDIRECT_BUFFER_BINDING',0x8F43)
GL_ELEMENT_ARRAY_BARRIER_BIT=_C('GL_ELEMENT_ARRAY_BARRIER_BIT',0x00000002)
GL_FRAGMENT_SHADER_BIT=_C('GL_FRAGMENT_SHADER_BIT',0x00000002)
GL_FRAMEBUFFER_BARRIER_BIT=_C('GL_FRAMEBUFFER_BARRIER_BIT',0x00000400)
GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS=_C('GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS',0x9314)
GL_FRAMEBUFFER_DEFAULT_HEIGHT=_C('GL_FRAMEBUFFER_DEFAULT_HEIGHT',0x9311)
GL_FRAMEBUFFER_DEFAULT_SAMPLES=_C('GL_FRAMEBUFFER_DEFAULT_SAMPLES',0x9313)
GL_FRAMEBUFFER_DEFAULT_WIDTH=_C('GL_FRAMEBUFFER_DEFAULT_WIDTH',0x9310)
GL_IMAGE_2D=_C('GL_IMAGE_2D',0x904D)
GL_IMAGE_2D_ARRAY=_C('GL_IMAGE_2D_ARRAY',0x9053)
GL_IMAGE_3D=_C('GL_IMAGE_3D',0x904E)
GL_IMAGE_BINDING_ACCESS=_C('GL_IMAGE_BINDING_ACCESS',0x8F3E)
GL_IMAGE_BINDING_FORMAT=_C('GL_IMAGE_BINDING_FORMAT',0x906E)
GL_IMAGE_BINDING_LAYER=_C('GL_IMAGE_BINDING_LAYER',0x8F3D)
GL_IMAGE_BINDING_LAYERED=_C('GL_IMAGE_BINDING_LAYERED',0x8F3C)
GL_IMAGE_BINDING_LEVEL=_C('GL_IMAGE_BINDING_LEVEL',0x8F3B)
GL_IMAGE_BINDING_NAME=_C('GL_IMAGE_BINDING_NAME',0x8F3A)
GL_IMAGE_CUBE=_C('GL_IMAGE_CUBE',0x9050)
GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS=_C('GL_IMAGE_FORMAT_COMPATIBILITY_BY_CLASS',0x90C9)
GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE=_C('GL_IMAGE_FORMAT_COMPATIBILITY_BY_SIZE',0x90C8)
GL_IMAGE_FORMAT_COMPATIBILITY_TYPE=_C('GL_IMAGE_FORMAT_COMPATIBILITY_TYPE',0x90C7)
GL_INT_IMAGE_2D=_C('GL_INT_IMAGE_2D',0x9058)
GL_INT_IMAGE_2D_ARRAY=_C('GL_INT_IMAGE_2D_ARRAY',0x905E)
GL_INT_IMAGE_3D=_C('GL_INT_IMAGE_3D',0x9059)
GL_INT_IMAGE_CUBE=_C('GL_INT_IMAGE_CUBE',0x905B)
GL_INT_SAMPLER_2D_MULTISAMPLE=_C('GL_INT_SAMPLER_2D_MULTISAMPLE',0x9109)
GL_IS_ROW_MAJOR=_C('GL_IS_ROW_MAJOR',0x9300)
GL_LOCATION=_C('GL_LOCATION',0x930E)
GL_MATRIX_STRIDE=_C('GL_MATRIX_STRIDE',0x92FF)
GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS=_C('GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS',0x92DC)
GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE=_C('GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE',0x92D8)
GL_MAX_COLOR_TEXTURE_SAMPLES=_C('GL_MAX_COLOR_TEXTURE_SAMPLES',0x910E)
GL_MAX_COMBINED_ATOMIC_COUNTERS=_C('GL_MAX_COMBINED_ATOMIC_COUNTERS',0x92D7)
GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS',0x92D1)
GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS',0x8266)
GL_MAX_COMBINED_IMAGE_UNIFORMS=_C('GL_MAX_COMBINED_IMAGE_UNIFORMS',0x90CF)
GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES=_C('GL_MAX_COMBINED_SHADER_OUTPUT_RESOURCES',0x8F39)
GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS=_C('GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS',0x90DC)
GL_MAX_COMPUTE_ATOMIC_COUNTERS=_C('GL_MAX_COMPUTE_ATOMIC_COUNTERS',0x8265)
GL_MAX_COMPUTE_ATOMIC_COUNTERS=_C('GL_MAX_COMPUTE_ATOMIC_COUNTERS',0x8265)
GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS',0x8264)
GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS',0x8264)
GL_MAX_COMPUTE_IMAGE_UNIFORMS=_C('GL_MAX_COMPUTE_IMAGE_UNIFORMS',0x91BD)
GL_MAX_COMPUTE_IMAGE_UNIFORMS=_C('GL_MAX_COMPUTE_IMAGE_UNIFORMS',0x91BD)
GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS=_C('GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS',0x90DB)
GL_MAX_COMPUTE_SHARED_MEMORY_SIZE=_C('GL_MAX_COMPUTE_SHARED_MEMORY_SIZE',0x8262)
GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS=_C('GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS',0x91BC)
GL_MAX_COMPUTE_UNIFORM_BLOCKS=_C('GL_MAX_COMPUTE_UNIFORM_BLOCKS',0x91BB)
GL_MAX_COMPUTE_UNIFORM_COMPONENTS=_C('GL_MAX_COMPUTE_UNIFORM_COMPONENTS',0x8263)
GL_MAX_COMPUTE_WORK_GROUP_COUNT=_C('GL_MAX_COMPUTE_WORK_GROUP_COUNT',0x91BE)
GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS=_C('GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS',0x90EB)
GL_MAX_COMPUTE_WORK_GROUP_SIZE=_C('GL_MAX_COMPUTE_WORK_GROUP_SIZE',0x91BF)
GL_MAX_DEPTH_TEXTURE_SAMPLES=_C('GL_MAX_DEPTH_TEXTURE_SAMPLES',0x910F)
GL_MAX_FRAGMENT_ATOMIC_COUNTERS=_C('GL_MAX_FRAGMENT_ATOMIC_COUNTERS',0x92D6)
GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS',0x92D0)
GL_MAX_FRAGMENT_IMAGE_UNIFORMS=_C('GL_MAX_FRAGMENT_IMAGE_UNIFORMS',0x90CE)
GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS=_C('GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS',0x90DA)
GL_MAX_FRAMEBUFFER_HEIGHT=_C('GL_MAX_FRAMEBUFFER_HEIGHT',0x9316)
GL_MAX_FRAMEBUFFER_SAMPLES=_C('GL_MAX_FRAMEBUFFER_SAMPLES',0x9318)
GL_MAX_FRAMEBUFFER_WIDTH=_C('GL_MAX_FRAMEBUFFER_WIDTH',0x9315)
GL_MAX_IMAGE_UNITS=_C('GL_MAX_IMAGE_UNITS',0x8F38)
GL_MAX_INTEGER_SAMPLES=_C('GL_MAX_INTEGER_SAMPLES',0x9110)
GL_MAX_NAME_LENGTH=_C('GL_MAX_NAME_LENGTH',0x92F6)
GL_MAX_NUM_ACTIVE_VARIABLES=_C('GL_MAX_NUM_ACTIVE_VARIABLES',0x92F7)
GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET=_C('GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET',0x8E5F)
GL_MAX_SAMPLE_MASK_WORDS=_C('GL_MAX_SAMPLE_MASK_WORDS',0x8E59)
GL_MAX_SHADER_STORAGE_BLOCK_SIZE=_C('GL_MAX_SHADER_STORAGE_BLOCK_SIZE',0x90DE)
GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS=_C('GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS',0x90DD)
GL_MAX_UNIFORM_LOCATIONS=_C('GL_MAX_UNIFORM_LOCATIONS',0x826E)
GL_MAX_VERTEX_ATOMIC_COUNTERS=_C('GL_MAX_VERTEX_ATOMIC_COUNTERS',0x92D2)
GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS',0x92CC)
GL_MAX_VERTEX_ATTRIB_BINDINGS=_C('GL_MAX_VERTEX_ATTRIB_BINDINGS',0x82DA)
GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET=_C('GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET',0x82D9)
GL_MAX_VERTEX_ATTRIB_STRIDE=_C('GL_MAX_VERTEX_ATTRIB_STRIDE',0x82E5)
GL_MAX_VERTEX_IMAGE_UNIFORMS=_C('GL_MAX_VERTEX_IMAGE_UNIFORMS',0x90CA)
GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS=_C('GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS',0x90D6)
GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET=_C('GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET',0x8E5E)
GL_NAME_LENGTH=_C('GL_NAME_LENGTH',0x92F9)
GL_NUM_ACTIVE_VARIABLES=_C('GL_NUM_ACTIVE_VARIABLES',0x9304)
GL_OFFSET=_C('GL_OFFSET',0x92FC)
GL_PIXEL_BUFFER_BARRIER_BIT=_C('GL_PIXEL_BUFFER_BARRIER_BIT',0x00000080)
GL_PROGRAM_INPUT=_C('GL_PROGRAM_INPUT',0x92E3)
GL_PROGRAM_OUTPUT=_C('GL_PROGRAM_OUTPUT',0x92E4)
GL_PROGRAM_PIPELINE_BINDING=_C('GL_PROGRAM_PIPELINE_BINDING',0x825A)
GL_PROGRAM_SEPARABLE=_C('GL_PROGRAM_SEPARABLE',0x8258)
GL_READ_ONLY=_C('GL_READ_ONLY',0x88B8)
GL_READ_WRITE=_C('GL_READ_WRITE',0x88BA)
GL_REFERENCED_BY_COMPUTE_SHADER=_C('GL_REFERENCED_BY_COMPUTE_SHADER',0x930B)
GL_REFERENCED_BY_FRAGMENT_SHADER=_C('GL_REFERENCED_BY_FRAGMENT_SHADER',0x930A)
GL_REFERENCED_BY_VERTEX_SHADER=_C('GL_REFERENCED_BY_VERTEX_SHADER',0x9306)
GL_SAMPLER_2D_MULTISAMPLE=_C('GL_SAMPLER_2D_MULTISAMPLE',0x9108)
GL_SAMPLE_MASK=_C('GL_SAMPLE_MASK',0x8E51)
GL_SAMPLE_MASK_VALUE=_C('GL_SAMPLE_MASK_VALUE',0x8E52)
GL_SAMPLE_POSITION=_C('GL_SAMPLE_POSITION',0x8E50)
GL_SHADER_IMAGE_ACCESS_BARRIER_BIT=_C('GL_SHADER_IMAGE_ACCESS_BARRIER_BIT',0x00000020)
GL_SHADER_STORAGE_BARRIER_BIT=_C('GL_SHADER_STORAGE_BARRIER_BIT',0x00002000)
GL_SHADER_STORAGE_BLOCK=_C('GL_SHADER_STORAGE_BLOCK',0x92E6)
GL_SHADER_STORAGE_BUFFER=_C('GL_SHADER_STORAGE_BUFFER',0x90D2)
GL_SHADER_STORAGE_BUFFER_BINDING=_C('GL_SHADER_STORAGE_BUFFER_BINDING',0x90D3)
GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT=_C('GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT',0x90DF)
GL_SHADER_STORAGE_BUFFER_SIZE=_C('GL_SHADER_STORAGE_BUFFER_SIZE',0x90D5)
GL_SHADER_STORAGE_BUFFER_START=_C('GL_SHADER_STORAGE_BUFFER_START',0x90D4)
GL_STENCIL_INDEX=_C('GL_STENCIL_INDEX',0x1901)
GL_TEXTURE_2D_MULTISAMPLE=_C('GL_TEXTURE_2D_MULTISAMPLE',0x9100)
GL_TEXTURE_ALPHA_SIZE=_C('GL_TEXTURE_ALPHA_SIZE',0x805F)
GL_TEXTURE_ALPHA_TYPE=_C('GL_TEXTURE_ALPHA_TYPE',0x8C13)
GL_TEXTURE_BINDING_2D_MULTISAMPLE=_C('GL_TEXTURE_BINDING_2D_MULTISAMPLE',0x9104)
GL_TEXTURE_BLUE_SIZE=_C('GL_TEXTURE_BLUE_SIZE',0x805E)
GL_TEXTURE_BLUE_TYPE=_C('GL_TEXTURE_BLUE_TYPE',0x8C12)
GL_TEXTURE_COMPRESSED=_C('GL_TEXTURE_COMPRESSED',0x86A1)
GL_TEXTURE_DEPTH=_C('GL_TEXTURE_DEPTH',0x8071)
GL_TEXTURE_DEPTH_SIZE=_C('GL_TEXTURE_DEPTH_SIZE',0x884A)
GL_TEXTURE_DEPTH_TYPE=_C('GL_TEXTURE_DEPTH_TYPE',0x8C16)
GL_TEXTURE_FETCH_BARRIER_BIT=_C('GL_TEXTURE_FETCH_BARRIER_BIT',0x00000008)
GL_TEXTURE_FIXED_SAMPLE_LOCATIONS=_C('GL_TEXTURE_FIXED_SAMPLE_LOCATIONS',0x9107)
GL_TEXTURE_GREEN_SIZE=_C('GL_TEXTURE_GREEN_SIZE',0x805D)
GL_TEXTURE_GREEN_TYPE=_C('GL_TEXTURE_GREEN_TYPE',0x8C11)
GL_TEXTURE_HEIGHT=_C('GL_TEXTURE_HEIGHT',0x1001)
GL_TEXTURE_INTERNAL_FORMAT=_C('GL_TEXTURE_INTERNAL_FORMAT',0x1003)
GL_TEXTURE_RED_SIZE=_C('GL_TEXTURE_RED_SIZE',0x805C)
GL_TEXTURE_RED_TYPE=_C('GL_TEXTURE_RED_TYPE',0x8C10)
GL_TEXTURE_SAMPLES=_C('GL_TEXTURE_SAMPLES',0x9106)
GL_TEXTURE_SHARED_SIZE=_C('GL_TEXTURE_SHARED_SIZE',0x8C3F)
GL_TEXTURE_STENCIL_SIZE=_C('GL_TEXTURE_STENCIL_SIZE',0x88F1)
GL_TEXTURE_UPDATE_BARRIER_BIT=_C('GL_TEXTURE_UPDATE_BARRIER_BIT',0x00000100)
GL_TEXTURE_WIDTH=_C('GL_TEXTURE_WIDTH',0x1000)
GL_TOP_LEVEL_ARRAY_SIZE=_C('GL_TOP_LEVEL_ARRAY_SIZE',0x930C)
GL_TOP_LEVEL_ARRAY_STRIDE=_C('GL_TOP_LEVEL_ARRAY_STRIDE',0x930D)
GL_TRANSFORM_FEEDBACK_BARRIER_BIT=_C('GL_TRANSFORM_FEEDBACK_BARRIER_BIT',0x00000800)
GL_TRANSFORM_FEEDBACK_VARYING=_C('GL_TRANSFORM_FEEDBACK_VARYING',0x92F4)
GL_TYPE=_C('GL_TYPE',0x92FA)
GL_UNIFORM=_C('GL_UNIFORM',0x92E1)
GL_UNIFORM_BARRIER_BIT=_C('GL_UNIFORM_BARRIER_BIT',0x00000004)
GL_UNIFORM_BLOCK=_C('GL_UNIFORM_BLOCK',0x92E2)
GL_UNSIGNED_INT_ATOMIC_COUNTER=_C('GL_UNSIGNED_INT_ATOMIC_COUNTER',0x92DB)
GL_UNSIGNED_INT_IMAGE_2D=_C('GL_UNSIGNED_INT_IMAGE_2D',0x9063)
GL_UNSIGNED_INT_IMAGE_2D_ARRAY=_C('GL_UNSIGNED_INT_IMAGE_2D_ARRAY',0x9069)
GL_UNSIGNED_INT_IMAGE_3D=_C('GL_UNSIGNED_INT_IMAGE_3D',0x9064)
GL_UNSIGNED_INT_IMAGE_CUBE=_C('GL_UNSIGNED_INT_IMAGE_CUBE',0x9066)
GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE=_C('GL_UNSIGNED_INT_SAMPLER_2D_MULTISAMPLE',0x910A)
GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT=_C('GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT',0x00000001)
GL_VERTEX_ATTRIB_BINDING=_C('GL_VERTEX_ATTRIB_BINDING',0x82D4)
GL_VERTEX_ATTRIB_RELATIVE_OFFSET=_C('GL_VERTEX_ATTRIB_RELATIVE_OFFSET',0x82D5)
GL_VERTEX_BINDING_BUFFER=_C('GL_VERTEX_BINDING_BUFFER',0x8F4F)
GL_VERTEX_BINDING_DIVISOR=_C('GL_VERTEX_BINDING_DIVISOR',0x82D6)
GL_VERTEX_BINDING_OFFSET=_C('GL_VERTEX_BINDING_OFFSET',0x82D7)
GL_VERTEX_BINDING_STRIDE=_C('GL_VERTEX_BINDING_STRIDE',0x82D8)
GL_VERTEX_SHADER_BIT=_C('GL_VERTEX_SHADER_BIT',0x00000001)
GL_WRITE_ONLY=_C('GL_WRITE_ONLY',0x88B9)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glActiveShaderProgram(pipeline,program):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLint,_cs.GLboolean,_cs.GLint,_cs.GLenum,_cs.GLenum)
def glBindImageTexture(unit,texture,level,layered,layer,access,format):pass
@_f
@_p.types(None,_cs.GLuint)
def glBindProgramPipeline(pipeline):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLsizei)
def glBindVertexBuffer(bindingindex,buffer,offset,stride):pass
@_f
@_p.types(_cs.GLuint,_cs.GLenum,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )))
def glCreateShaderProgramv(type,count,strings):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteProgramPipelines(n,pipelines):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glDispatchCompute(num_groups_x,num_groups_y,num_groups_z):pass
@_f
@_p.types(None,_cs.GLintptr)
def glDispatchComputeIndirect(indirect):pass
@_f
@_p.types(None,_cs.GLenum,ctypes.c_void_p)
def glDrawArraysIndirect(mode,indirect):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glDrawElementsIndirect(mode,type,indirect):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glFramebufferParameteri(target,pname,param):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenProgramPipelines(n,pipelines):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLbooleanArray)
def glGetBooleani_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFramebufferParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetMultisamplefv(pname,index,val):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetProgramInterfaceiv(program,programInterface,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetProgramPipelineInfoLog(pipeline,bufSize,length,infoLog):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetProgramPipelineiv(pipeline,pname,params):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetProgramResourceIndex(program,programInterface,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetProgramResourceLocation(program,programInterface,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetProgramResourceName(program,programInterface,index,bufSize,length,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetProgramResourceiv(program,programInterface,index,propCount,props,bufSize,length,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLfloatArray)
def glGetTexLevelParameterfv(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLintArray)
def glGetTexLevelParameteriv(target,level,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsProgramPipeline(pipeline):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glMemoryBarrier(barriers):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glMemoryBarrierByRegion(barriers):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat)
def glProgramUniform1f(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform1fv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint)
def glProgramUniform1i(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform1iv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint)
def glProgramUniform1ui(program,location,v0):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform1uiv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform2f(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform2fv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform2i(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform2iv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint)
def glProgramUniform2ui(program,location,v0,v1):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform2uiv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform3f(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform3fv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform3i(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform3iv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glProgramUniform3ui(program,location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform3uiv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glProgramUniform4f(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glProgramUniform4fv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glProgramUniform4i(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glProgramUniform4iv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glProgramUniform4ui(program,location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glProgramUniform4uiv(program,location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2x3fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix2x4fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3x2fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix3x4fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4x2fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glProgramUniformMatrix4x3fv(program,location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield)
def glSampleMaski(maskNumber,mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLboolean)
def glTexStorage2DMultisample(target,samples,internalformat,width,height,fixedsamplelocations):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLbitfield,_cs.GLuint)
def glUseProgramStages(pipeline,stages,program):pass
@_f
@_p.types(None,_cs.GLuint)
def glValidateProgramPipeline(pipeline):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribBinding(attribindex,bindingindex):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribFormat(attribindex,size,type,normalized,relativeoffset):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLuint)
def glVertexAttribIFormat(attribindex,size,type,relativeoffset):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexBindingDivisor(bindingindex,divisor):pass



'''OpenGL extension EXT.texture_mirror_clamp

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_mirror_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_texture_mirror_clamp extends the set of texture wrap modes to
	include three modes (GL_MIRROR_CLAMP_EXT, GL_MIRROR_CLAMP_TO_EDGE_EXT,
	GL_MIRROR_CLAMP_TO_BORDER_EXT) that effectively use a texture map
	twice as large as the original image in which the additional half
	of the new image is a mirror image of the original image.
	
	This new mode relaxes the need to generate images whose opposite
	edges match by using the original image to generate a matching
	"mirror image".  This mode allows the texture to be mirrored only
	once in the negative s, t, and r directions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_mirror_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_mirror_clamp import *
from OpenGL.raw.GL.EXT.texture_mirror_clamp import _EXTENSION_NAME

def glInitTextureMirrorClampEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.shader_thread_shuffle

This module customises the behaviour of the 
OpenGL.raw.GL.NV.shader_thread_shuffle to provide a more 
Python-friendly API

Overview (from the spec)
	
	Implementations of the OpenGL Shading Language may, but are not required, 
	to run multiple shader threads for a single stage as a SIMD thread group, 
	where individual execution threads are assigned to thread groups in an 
	undefined, implementation-dependent order.  This extension provides a set 
	of new features to the OpenGL Shading Language to share data between 
	multiple threads within a thread group. 
	
	Shaders using the new functionalities provided by this extension should 
	enable this functionality via the construct
	
	    #extension GL_NV_shader_thread_shuffle : require     (or enable)
	
	This extension also specifies some modifications to the program assembly
	language to support the thread data sharing functionalities.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shader_thread_shuffle.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.shader_thread_shuffle import *
from OpenGL.raw.GL.NV.shader_thread_shuffle import _EXTENSION_NAME

def glInitShaderThreadShuffleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.light_texture

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.light_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a general mechanism for substituting the
	fragment color computed during texture environment processing in
	place of other fragment attributes such as the fragment normal, or
	as sources for some of the computations in the fragment processing
	pipeline, for example as material or light parameters in the
	fragment lighting computations.
	
	
	Cf ----------------------+
	                         |                 +-> to lighting parameters
	                         v                 |
	+------------+        +--------+     +-------------+
	|            |        |        |     |             |
	| texel      |------->| texenv |-----| texture     |---> Cf' (to Light Environment
	| generation |        |        |     | application |          or Fog)
	|            |        |        |     |             |
	+------------+        +--------+     +-------------+
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/light_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.light_texture import *
from OpenGL.raw.GL.EXT.light_texture import _EXTENSION_NAME

def glInitLightTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_color_buffer_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_color_buffer_float',error_checker=_errors._error_checker)
GL_CLAMP_FRAGMENT_COLOR_ARB=_C('GL_CLAMP_FRAGMENT_COLOR_ARB',0x891B)
GL_CLAMP_READ_COLOR_ARB=_C('GL_CLAMP_READ_COLOR_ARB',0x891C)
GL_CLAMP_VERTEX_COLOR_ARB=_C('GL_CLAMP_VERTEX_COLOR_ARB',0x891A)
GL_FIXED_ONLY_ARB=_C('GL_FIXED_ONLY_ARB',0x891D)
GL_RGBA_FLOAT_MODE_ARB=_C('GL_RGBA_FLOAT_MODE_ARB',0x8820)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glClampColorARB(target,clamp):pass



'''OpenGL extension IBM.vertex_array_lists

This module customises the behaviour of the 
OpenGL.raw.GL.IBM.vertex_array_lists to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces seven (7) new functions that set the 
	vertex array pointers. However, instead of a single pointer, these
	functions provide a list of array pointers that can be used by the 
	EXT_multi_draw_arrays and IBM_multimode_draw_arrays extension 
	functions to draw from multiple of vertex arrays. The first 
	primitive will use the first array in the list, the second primitive
	will use the second array in the list, and so forth. If a glDrawArray,
	DrawElements, or DrawRangeElements function is used, then 
	only the first vertex array in the list is used.
	
	When a vertex array list is specified, only the list pointer
	is kept by the underlying OpenGL function. Therefore, the list
	must be staticly defined for the entire duration of its usage,
	much in the same manner as the vertex arrays themselves. Also
	note that the list function can therefore also be used to change
	array pointers without making a OpenGL API function call.
	
	A <ptrstride> value of zero (0) can be used to force all primitives
	of a multi-vertex array to use only the first vertex array in 
	the list. 
	
	The <stride> parameter of the list pointer functions differs from
	that of the non-list vertex array pointer functions in that 1)
	both negative and positive strides are accepted thusly allowing
	vertex lists to be rendered in reverse order; 2) a <stride> of
	zero (0) results in no stride and can be used to specify a single
	vertex attribute for each vertex of the primitive.
	
	These new functions are a superset of the standard OpenGL 1.2 vertex
	array (non-list) pointer functions and share common state. Therefore,
	the list pointer and non-list pointer functions can be used
	interchangably.
	
	New queries are provided by this extension so that ZAPdb can be extended
	to query the list pointer state whenever a vertex array function 
	is traced. The pointer returned by a query of *_ARRAY_POINTER returns
	the first entry in the array list.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IBM/vertex_array_lists.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.IBM.vertex_array_lists import *
from OpenGL.raw.GL.IBM.vertex_array_lists import _EXTENSION_NAME

def glInitVertexArrayListsIBM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glColorPointerListIBM.pointer size not checked against 'size,type,stride'
glColorPointerListIBM=wrapper.wrapper(glColorPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glSecondaryColorPointerListIBM.pointer size not checked against 'size,type,stride'
glSecondaryColorPointerListIBM=wrapper.wrapper(glSecondaryColorPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glEdgeFlagPointerListIBM.pointer size not checked against 'stride'
glEdgeFlagPointerListIBM=wrapper.wrapper(glEdgeFlagPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glFogCoordPointerListIBM.pointer size not checked against 'type,stride'
glFogCoordPointerListIBM=wrapper.wrapper(glFogCoordPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glIndexPointerListIBM.pointer size not checked against 'type,stride'
glIndexPointerListIBM=wrapper.wrapper(glIndexPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glNormalPointerListIBM.pointer size not checked against 'type,stride'
glNormalPointerListIBM=wrapper.wrapper(glNormalPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glTexCoordPointerListIBM.pointer size not checked against 'size,type,stride'
glTexCoordPointerListIBM=wrapper.wrapper(glTexCoordPointerListIBM).setInputArraySize(
    'pointer', None
)
# INPUT glVertexPointerListIBM.pointer size not checked against 'size,type,stride'
glVertexPointerListIBM=wrapper.wrapper(glVertexPointerListIBM).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_packed_depth_stencil'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_packed_depth_stencil',error_checker=_errors._error_checker)
GL_DEPTH24_STENCIL8_EXT=_C('GL_DEPTH24_STENCIL8_EXT',0x88F0)
GL_DEPTH_STENCIL_EXT=_C('GL_DEPTH_STENCIL_EXT',0x84F9)
GL_TEXTURE_STENCIL_SIZE_EXT=_C('GL_TEXTURE_STENCIL_SIZE_EXT',0x88F1)
GL_UNSIGNED_INT_24_8_EXT=_C('GL_UNSIGNED_INT_24_8_EXT',0x84FA)




"""Implementations for "held-pointers" of various types

This argument type is special because it is stored, that is, it
needs to be cached on our side so that the memory address does not
go out-of-scope

storedPointers = {}
def glVertexPointerd( array ):
    "Natural writing of glVertexPointerd using standard ctypes"
    arg2 = GL_DOUBLE
    arg3 = 0 # stride
    arg4 = arrays.asArray(array, GL_DOUBLE)
    arg1 = arrays.arraySize( arg4, 'd' )
    platform.PLATFORM.GL.glVertexPointer( arg1, arg2, arg3, arrays.ArrayDatatype.dataPointer(arg4) )
    # only store if we successfully set the value...
    storedPointers[ GL_VERTEX_ARRAY ] = arg4
    return arg4
"""
from OpenGL import platform, error, wrapper, contextdata, converters, constant
from OpenGL.arrays import arrayhelpers, arraydatatype
from OpenGL.raw.GL.VERSION import GL_1_1 as _simple
import ctypes

GLsizei = ctypes.c_int
GLenum = ctypes.c_uint
GLint = ctypes.c_int
# OpenGL-ctypes variables that mimic OpenGL constant operation...
GL_INTERLEAVED_ARRAY_POINTER = constant.Constant( 'GL_INTERLEAVED_ARRAY_POINTER', -32910 )

__all__ = (
    'glColorPointer',
    'glColorPointerb','glColorPointerd','glColorPointerf','glColorPointeri',
    'glColorPointers','glColorPointerub','glColorPointerui','glColorPointerus',
    'glEdgeFlagPointer',
    'glEdgeFlagPointerb',
    'glIndexPointer',
    'glIndexPointerb','glIndexPointerd','glIndexPointerf',
    'glIndexPointeri','glIndexPointers','glIndexPointerub',
    'glNormalPointer',
    'glNormalPointerb',
    'glNormalPointerd','glNormalPointerf','glNormalPointeri','glNormalPointers',
    'glTexCoordPointer',
    'glTexCoordPointerb','glTexCoordPointerd','glTexCoordPointerf',
    'glTexCoordPointeri','glTexCoordPointers',
    'glVertexPointer',
    'glVertexPointerb','glVertexPointerd','glVertexPointerf','glVertexPointeri',
    'glVertexPointers',
    'glDrawElements','glDrawElementsui','glDrawElementsub','glDrawElementsus',
    'glFeedbackBuffer',
    'glSelectBuffer',
    'glRenderMode',
    'glGetPointerv',
    'glInterleavedArrays',
    'GL_INTERLEAVED_ARRAY_POINTER',
)


# Have to create *new* ctypes wrappers for the platform object!
# We can't just alter the default one since we have different ways of
# calling it

POINTER_FUNCTION_DATA = [
    ('glColorPointerd',  _simple.glColorPointer, _simple.GL_DOUBLE, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointerf',  _simple.glColorPointer, _simple.GL_FLOAT, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointeri',  _simple.glColorPointer, _simple.GL_INT, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointers',  _simple.glColorPointer, _simple.GL_SHORT, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointerub', _simple.glColorPointer, _simple.GL_UNSIGNED_BYTE, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    # these data-types are mapped from diff Numeric types
    ('glColorPointerb',  _simple.glColorPointer, _simple.GL_BYTE, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointerui', _simple.glColorPointer, _simple.GL_UNSIGNED_INT, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),
    ('glColorPointerus', _simple.glColorPointer, _simple.GL_UNSIGNED_SHORT, _simple.GL_COLOR_ARRAY_POINTER, 0, 3),

    ('glEdgeFlagPointerb', _simple.glEdgeFlagPointer, _simple.GL_BYTE, _simple.GL_EDGE_FLAG_ARRAY_POINTER, 2, None),

    ('glIndexPointerd',  _simple.glIndexPointer, _simple.GL_DOUBLE, _simple.GL_INDEX_ARRAY_POINTER, 1, None),
    ('glIndexPointerf',  _simple.glIndexPointer, _simple.GL_FLOAT, _simple.GL_INDEX_ARRAY_POINTER, 1, None),
    ('glIndexPointeri',  _simple.glIndexPointer, _simple.GL_INT, _simple.GL_INDEX_ARRAY_POINTER, 1, None),
    ('glIndexPointerub', _simple.glIndexPointer, _simple.GL_UNSIGNED_BYTE, _simple.GL_INDEX_ARRAY_POINTER, 1, None),
    ('glIndexPointers',  _simple.glIndexPointer, _simple.GL_SHORT, _simple.GL_INDEX_ARRAY_POINTER, 1, None),
    # these data-types are mapped from diff Numeric types
    ('glIndexPointerb',  _simple.glIndexPointer, _simple.GL_BYTE, _simple.GL_INDEX_ARRAY_POINTER, 1, None),

    ('glNormalPointerd',  _simple.glNormalPointer, _simple.GL_DOUBLE, _simple.GL_NORMAL_ARRAY_POINTER, 1, None),
    ('glNormalPointerf',  _simple.glNormalPointer, _simple.GL_FLOAT, _simple.GL_NORMAL_ARRAY_POINTER, 1, None),
    ('glNormalPointeri',  _simple.glNormalPointer, _simple.GL_INT, _simple.GL_NORMAL_ARRAY_POINTER, 1, None),
    ('glNormalPointerb',  _simple.glNormalPointer, _simple.GL_BYTE, _simple.GL_NORMAL_ARRAY_POINTER, 1, None),
    ('glNormalPointers',  _simple.glNormalPointer, _simple.GL_SHORT, _simple.GL_NORMAL_ARRAY_POINTER, 1, None),

    ('glTexCoordPointerd',  _simple.glTexCoordPointer, _simple.GL_DOUBLE, _simple.GL_TEXTURE_COORD_ARRAY_POINTER, 0, 2),
    ('glTexCoordPointerf',  _simple.glTexCoordPointer, _simple.GL_FLOAT, _simple.GL_TEXTURE_COORD_ARRAY_POINTER, 0, 2),
    ('glTexCoordPointeri',  _simple.glTexCoordPointer, _simple.GL_INT, _simple.GL_TEXTURE_COORD_ARRAY_POINTER, 0, 2),
    ('glTexCoordPointerb',  _simple.glTexCoordPointer, _simple.GL_BYTE, _simple.GL_TEXTURE_COORD_ARRAY_POINTER, 0, 2),
    ('glTexCoordPointers',  _simple.glTexCoordPointer, _simple.GL_SHORT, _simple.GL_TEXTURE_COORD_ARRAY_POINTER, 0, 2),

    ('glVertexPointerd', _simple.glVertexPointer, _simple.GL_DOUBLE, _simple.GL_VERTEX_ARRAY_POINTER, 0, 3),
    ('glVertexPointerf', _simple.glVertexPointer, _simple.GL_FLOAT, _simple.GL_VERTEX_ARRAY_POINTER, 0, 3),
    ('glVertexPointeri', _simple.glVertexPointer, _simple.GL_INT, _simple.GL_VERTEX_ARRAY_POINTER, 0, 3),
    ('glVertexPointerb', _simple.glVertexPointer, _simple.GL_INT, _simple.GL_VERTEX_ARRAY_POINTER, 0, 3),
    ('glVertexPointers', _simple.glVertexPointer, _simple.GL_SHORT, _simple.GL_VERTEX_ARRAY_POINTER, 0, 3),
]
def wrapPointerFunction( name, baseFunction, glType, arrayType,startArgs, defaultSize ):
    """Wrap the given pointer-setting function"""
    function= wrapper.wrapper( baseFunction )
    if 'ptr' in baseFunction.argNames:
        pointer_name = 'ptr'
    else:
        pointer_name = 'pointer'
    assert not getattr( function, 'pyConverters', None ), """Reusing wrappers?"""
    if arrayType:
        arrayModuleType = arraydatatype.GL_CONSTANT_TO_ARRAY_TYPE[ glType ]
        function.setPyConverter( pointer_name, arrayhelpers.asArrayType(arrayModuleType) )
    else:
        function.setPyConverter( pointer_name, arrayhelpers.AsArrayOfType(pointer_name,'type') )
    function.setCConverter( pointer_name, converters.getPyArgsName( pointer_name ) )
    if 'size' in function.argNames:
        function.setPyConverter( 'size' )
        function.setCConverter( 'size', arrayhelpers.arraySizeOfFirstType(arrayModuleType,defaultSize) )
    if 'type' in function.argNames:
        function.setPyConverter( 'type' )
        function.setCConverter( 'type', glType )
    if 'stride' in function.argNames:
        function.setPyConverter( 'stride' )
        function.setCConverter( 'stride', 0 )
    function.setStoreValues( arrayhelpers.storePointerType( pointer_name, arrayType ) )
    function.setReturnValues( wrapper.returnPyArgument( pointer_name ) )
    return name,function



for name,function in [
    wrapPointerFunction( *args )
    for args in POINTER_FUNCTION_DATA
]:
    globals()[name] = function
try:
    del name, function
except NameError as err:
    pass

glVertexPointer = wrapper.wrapper( _simple.glVertexPointer ).setPyConverter(
    'pointer', arrayhelpers.AsArrayOfType( 'pointer', 'type' ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_VERTEX_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glTexCoordPointer = wrapper.wrapper( _simple.glTexCoordPointer ).setPyConverter(
    'pointer', arrayhelpers.AsArrayOfType( 'pointer', 'type' ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_TEXTURE_COORD_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glNormalPointer = wrapper.wrapper( _simple.glNormalPointer ).setPyConverter(
    'pointer', arrayhelpers.AsArrayOfType( 'pointer', 'type' ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_NORMAL_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glIndexPointer = wrapper.wrapper( _simple.glIndexPointer ).setPyConverter(
    'pointer', arrayhelpers.AsArrayOfType( 'pointer', 'type' ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_INDEX_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glEdgeFlagPointer = wrapper.wrapper( _simple.glEdgeFlagPointer ).setPyConverter(
    # XXX type is wrong!
    'pointer', arrayhelpers.AsArrayTyped( 'pointer', arraydatatype.GLushortArray ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_EDGE_FLAG_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glColorPointer = wrapper.wrapper( _simple.glColorPointer ).setPyConverter(
    'pointer', arrayhelpers.AsArrayOfType( 'pointer', 'type' ),
).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', _simple.GL_COLOR_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)
glInterleavedArrays = wrapper.wrapper( _simple.glInterleavedArrays ).setStoreValues(
    arrayhelpers.storePointerType( 'pointer', GL_INTERLEAVED_ARRAY_POINTER )
).setReturnValues(
    wrapper.returnPyArgument( 'pointer' )
)


glDrawElements = wrapper.wrapper( _simple.glDrawElements ).setPyConverter(
    'indices', arrayhelpers.AsArrayOfType( 'indices', 'type' ),
).setReturnValues(
    wrapper.returnPyArgument( 'indices' )
)

def glDrawElementsTyped( type, suffix ):
    arrayType = arraydatatype.GL_CONSTANT_TO_ARRAY_TYPE[ type ]
    function = wrapper.wrapper(
        _simple.glDrawElements
    ).setPyConverter('type').setCConverter(
        'type', type
    ).setPyConverter('count').setCConverter(
        'count', arrayhelpers.AsArrayTypedSize( 'indices', arrayType ),
    ).setPyConverter(
        'indices', arrayhelpers.AsArrayTyped( 'indices', arrayType ),
    ).setReturnValues(
        wrapper.returnPyArgument( 'indices' )
    )
    return function
for type,suffix in ((_simple.GL_UNSIGNED_BYTE,'ub'),(_simple.GL_UNSIGNED_INT,'ui'),(_simple.GL_UNSIGNED_SHORT,'us')):
    globals()['glDrawElements%(suffix)s'%globals()] = glDrawElementsTyped( type,suffix )
try:
    del type,suffix,glDrawElementsTyped
except NameError as err:
    pass

# create buffer of given size and return it for future reference
# keep a per-context weakref around to allow us to return the original
# array we returned IFF the user has kept a reference as well...
def glSelectBuffer( size, buffer = None ):
    """Create a selection buffer of the given size
    """
    if buffer is None:
        buffer = arraydatatype.GLuintArray.zeros( (size,) )
    _simple.glSelectBuffer( size, buffer )
    contextdata.setValue( _simple.GL_SELECTION_BUFFER_POINTER, buffer )
    return buffer
def glFeedbackBuffer( size, type, buffer = None ):
    """Create a selection buffer of the given size
    """
    if buffer is None:
        buffer = arraydatatype.GLfloatArray.zeros( (size,) )
    _simple.glFeedbackBuffer( size, type, buffer )
    contextdata.setValue( _simple.GL_FEEDBACK_BUFFER_POINTER, buffer )
    contextdata.setValue( "GL_FEEDBACK_BUFFER_TYPE", type )
    return buffer

def glRenderMode( newMode ):
    """Change to the given rendering mode

    If the current mode is GL_FEEDBACK or GL_SELECT, return
    the current buffer appropriate to the mode
    """
    # must get the current mode to determine operation...
    from OpenGL.GL import glGetIntegerv
    from OpenGL.GL import selection, feedback
    currentMode = glGetIntegerv( _simple.GL_RENDER_MODE )
    try:
        currentMode = currentMode[0]
    except (TypeError,ValueError,IndexError) as err:
        pass
    if currentMode in (_simple.GL_RENDER,0):
        # no array needs to be returned...
        return _simple.glRenderMode( newMode )
    result = _simple.glRenderMode( newMode )
    # result is now an integer telling us how many elements were copied...

    if result < 0:
        if currentMode == _simple.GL_SELECT:
            raise error.GLError(
                _simple.GL_STACK_OVERFLOW,
                "glSelectBuffer too small to hold selection results",
            )
        elif currentMode == _simple.GL_FEEDBACK:
            raise error.GLError(
                _simple.GL_STACK_OVERFLOW,
                "glFeedbackBuffer too small to hold selection results",
            )
        else:
            raise error.GLError(
                _simple.GL_STACK_OVERFLOW,
                "Unknown glRenderMode buffer (%s) too small to hold selection results"%(
                    currentMode,
                ),
            )
    # Okay, now that the easy cases are out of the way...
    #  Do we have a pre-stored pointer about which the user already knows?
    context = platform.GetCurrentContext()
    if context == 0:
        raise error.Error(
            """Returning from glRenderMode without a valid context!"""
        )
    arrayConstant, wrapperFunction = {
        _simple.GL_FEEDBACK: (_simple.GL_FEEDBACK_BUFFER_POINTER,feedback.parseFeedback),
        _simple.GL_SELECT: (_simple.GL_SELECTION_BUFFER_POINTER, selection.GLSelectRecord.fromArray),
    }[ currentMode ]
    current = contextdata.getValue( arrayConstant )
    # XXX check to see if it's the *same* array we set currently!
    if current is None:
        current = glGetPointerv( arrayConstant )
    # XXX now, can turn the array into the appropriate wrapper type...
    if wrapperFunction:
        current = wrapperFunction( current, result )
    return current

# XXX this belongs in the GL module, not here!
def glGetPointerv( constant ):
    """Retrieve a stored pointer constant"""
    # do we have a cached version of the pointer?
    # get the base pointer from the underlying operation
    vp = ctypes.voidp()
    _simple.glGetPointerv( constant, ctypes.byref(vp) )
    current = contextdata.getValue( constant )
    if current is not None:
        if arraydatatype.ArrayDatatype.dataPointer( current ) == vp.value:
            return current
    # XXX should be coercing to the proper type and converting to an array
    return vp



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_half_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_half_float',error_checker=_errors._error_checker)
GL_HALF_FLOAT_NV=_C('GL_HALF_FLOAT_NV',0x140B)
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glColor3hNV(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor3hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glColor4hNV(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor4hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV)
def glFogCoordhNV(fog):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glFogCoordhvNV(fog):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLhalfNV)
def glMultiTexCoord1hNV(target,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glMultiTexCoord1hvNV(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLhalfNV,_cs.GLhalfNV)
def glMultiTexCoord2hNV(target,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glMultiTexCoord2hvNV(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glMultiTexCoord3hNV(target,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glMultiTexCoord3hvNV(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glMultiTexCoord4hNV(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glMultiTexCoord4hvNV(target,v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glNormal3hNV(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glNormal3hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glSecondaryColor3hNV(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glSecondaryColor3hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV)
def glTexCoord1hNV(s):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glTexCoord1hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV)
def glTexCoord2hNV(s,t):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glTexCoord2hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glTexCoord3hNV(s,t,r):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glTexCoord3hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glTexCoord4hNV(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glTexCoord4hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertex2hNV(x,y):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glVertex2hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertex3hNV(x,y,z):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glVertex3hvNV(v):pass
@_f
@_p.types(None,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertex4hNV(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glVertex4hvNV(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLhalfNV)
def glVertexAttrib1hNV(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib1hvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertexAttrib2hNV(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib2hvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertexAttrib3hNV(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib3hvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV,_cs.GLhalfNV)
def glVertexAttrib4hNV(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib4hvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLushortArray)
def glVertexAttribs1hvNV(index,n,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLushortArray)
def glVertexAttribs2hvNV(index,n,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLushortArray)
def glVertexAttribs3hvNV(index,n,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLushortArray)
def glVertexAttribs4hvNV(index,n,v):pass
@_f
@_p.types(None,_cs.GLhalfNV)
def glVertexWeighthNV(weight):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glVertexWeighthvNV(weight):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_geometry_shader4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_geometry_shader4',error_checker=_errors._error_checker)
GL_FRAMEBUFFER_ATTACHMENT_LAYERED_ARB=_C('GL_FRAMEBUFFER_ATTACHMENT_LAYERED_ARB',0x8DA7)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER',0x8CD4)
GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_ARB=_C('GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_ARB',0x8DA9)
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_ARB=_C('GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_ARB',0x8DA8)
GL_GEOMETRY_INPUT_TYPE_ARB=_C('GL_GEOMETRY_INPUT_TYPE_ARB',0x8DDB)
GL_GEOMETRY_OUTPUT_TYPE_ARB=_C('GL_GEOMETRY_OUTPUT_TYPE_ARB',0x8DDC)
GL_GEOMETRY_SHADER_ARB=_C('GL_GEOMETRY_SHADER_ARB',0x8DD9)
GL_GEOMETRY_VERTICES_OUT_ARB=_C('GL_GEOMETRY_VERTICES_OUT_ARB',0x8DDA)
GL_LINES_ADJACENCY_ARB=_C('GL_LINES_ADJACENCY_ARB',0x000A)
GL_LINE_STRIP_ADJACENCY_ARB=_C('GL_LINE_STRIP_ADJACENCY_ARB',0x000B)
GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB=_C('GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB',0x8DE0)
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB=_C('GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB',0x8C29)
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB=_C('GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB',0x8DE1)
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB=_C('GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB',0x8DDF)
GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB=_C('GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB',0x8DDD)
GL_MAX_VARYING_COMPONENTS=_C('GL_MAX_VARYING_COMPONENTS',0x8B4B)
GL_MAX_VERTEX_VARYING_COMPONENTS_ARB=_C('GL_MAX_VERTEX_VARYING_COMPONENTS_ARB',0x8DDE)
GL_PROGRAM_POINT_SIZE_ARB=_C('GL_PROGRAM_POINT_SIZE_ARB',0x8642)
GL_TRIANGLES_ADJACENCY_ARB=_C('GL_TRIANGLES_ADJACENCY_ARB',0x000C)
GL_TRIANGLE_STRIP_ADJACENCY_ARB=_C('GL_TRIANGLE_STRIP_ADJACENCY_ARB',0x000D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTextureARB(target,attachment,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLenum)
def glFramebufferTextureFaceARB(target,attachment,texture,level,face):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTextureLayerARB(target,attachment,texture,level,layer):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glProgramParameteriARB(program,pname,value):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_buffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_buffer_object',error_checker=_errors._error_checker)
GL_MAX_TEXTURE_BUFFER_SIZE_ARB=_C('GL_MAX_TEXTURE_BUFFER_SIZE_ARB',0x8C2B)
GL_TEXTURE_BINDING_BUFFER_ARB=_C('GL_TEXTURE_BINDING_BUFFER_ARB',0x8C2C)
GL_TEXTURE_BUFFER_ARB=_C('GL_TEXTURE_BUFFER_ARB',0x8C2A)
GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB=_C('GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB',0x8C2D)
GL_TEXTURE_BUFFER_FORMAT_ARB=_C('GL_TEXTURE_BUFFER_FORMAT_ARB',0x8C2E)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glTexBufferARB(target,internalformat,buffer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_KHR_blend_equation_advanced'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_KHR_blend_equation_advanced',error_checker=_errors._error_checker)
GL_COLORBURN_KHR=_C('GL_COLORBURN_KHR',0x929A)
GL_COLORDODGE_KHR=_C('GL_COLORDODGE_KHR',0x9299)
GL_DARKEN_KHR=_C('GL_DARKEN_KHR',0x9297)
GL_DIFFERENCE_KHR=_C('GL_DIFFERENCE_KHR',0x929E)
GL_EXCLUSION_KHR=_C('GL_EXCLUSION_KHR',0x92A0)
GL_HARDLIGHT_KHR=_C('GL_HARDLIGHT_KHR',0x929B)
GL_HSL_COLOR_KHR=_C('GL_HSL_COLOR_KHR',0x92AF)
GL_HSL_HUE_KHR=_C('GL_HSL_HUE_KHR',0x92AD)
GL_HSL_LUMINOSITY_KHR=_C('GL_HSL_LUMINOSITY_KHR',0x92B0)
GL_HSL_SATURATION_KHR=_C('GL_HSL_SATURATION_KHR',0x92AE)
GL_LIGHTEN_KHR=_C('GL_LIGHTEN_KHR',0x9298)
GL_MULTIPLY_KHR=_C('GL_MULTIPLY_KHR',0x9294)
GL_OVERLAY_KHR=_C('GL_OVERLAY_KHR',0x9296)
GL_SCREEN_KHR=_C('GL_SCREEN_KHR',0x9295)
GL_SOFTLIGHT_KHR=_C('GL_SOFTLIGHT_KHR',0x929C)
@_f
@_p.types(None,)
def glBlendBarrierKHR():pass



'''OpenGL extension NV.primitive_restart

This module customises the behaviour of the 
OpenGL.raw.GL.NV.primitive_restart to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows applications to easily and inexpensively
	restart a primitive in its middle.  A "primitive restart" is simply
	the same as an End command, followed by another Begin command with
	the same mode as the original.  The typical expected use of this
	feature is to draw a mesh with many triangle strips, though primitive
	restarts are legal for all primitive types, even for points (where
	they are not useful).
	
	Although the EXT_multi_draw_arrays extension did reduce the overhead
	of such drawing techniques, they still remain more expensive than one
	would like.
	
	This extension provides an extremely lightweight primitive restart,
	which is accomplished by allowing the application to choose a special
	index number that signals that a primitive restart should occur,
	rather than a vertex being provoked.  This index can be an arbitrary
	32-bit integer for maximum application convenience.
	
	In addition, for full orthogonality, a special OpenGL command is
	provided to restart primitives when in immediate mode.  This command
	is not likely to increase performance in any significant fashion, but
	providing it greatly simplifies the specification and implementation
	of display list compilation and indirect rendering.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/primitive_restart.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.primitive_restart import *
from OpenGL.raw.GL.NV.primitive_restart import _EXTENSION_NAME

def glInitPrimitiveRestartNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.compute_shader

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.compute_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	Recent graphics hardware has become extremely powerful and a strong desire
	to harness this power for work (both graphics and non-graphics) that does
	not fit the traditional graphics pipeline well has emerged. To address
	this, this extension adds a new single-stage program type known as a
	compute program. This program may contain one or more compute shaders
	which may be launched in a manner that is essentially stateless. This allows
	arbitrary workloads to be sent to the graphics hardware with minimal
	disturbance to the GL state machine.
	
	In most respects, a compute program is identical to a traditional OpenGL
	program object, with similar status, uniforms, and other such properties.
	It has access to many of the same resources as fragment and other shader
	types, such as textures, image variables, atomic counters, and so on.
	However, it has no predefined inputs nor any fixed-function outputs. It
	cannot be part of a pipeline and its visible side effects are through its
	actions on images and atomic counters.
	
	OpenCL is another solution for using graphics processors as generalized
	compute devices. This extension addresses a different need. For example,
	OpenCL is designed to be usable on a wide range of devices ranging from
	CPUs, GPUs, and DSPs through to FPGAs. While one could implement GL on these
	types of devices, the target here is clearly GPUs. Another difference is
	that OpenCL is more full featured and includes features such as multiple
	devices, asynchronous queues and strict IEEE semantics for floating point
	operations. This extension follows the semantics of OpenGL - implicitly
	synchronous, in-order operation with single-device, single queue
	logical architecture and somewhat more relaxed numerical precision
	requirements. Although not as feature rich, this extension offers several
	advantages for applications that can tolerate the omission of these
	features. Compute shaders are written in GLSL, for example and so code may
	be shared between compute and other shader types. Objects are created and
	owned by the same context as the rest of the GL, and therefore no
	interoperability API is required and objects may be freely used by both
	compute and graphics simultaneously without acquire-release semantics or
	object type translation.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/compute_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.compute_shader import *
from OpenGL.raw.GL.ARB.compute_shader import _EXTENSION_NAME

def glInitComputeShaderARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.sample_positions

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.sample_positions to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to explicitly set sample positions for a
	FBO with multi-sampled attachments. The FBO will use identical sample locations
	for all pixels in each attachment. This forces TEXTURE_FIXED_SAMPLE_LOCATIONS
	to TRUE if a multi-sampled texture is specified using TexImage2DMultisample
	or TexImage3DMultisample. That is, using GetTexLevelParameter to query
	TEXTURE_FIXED_SAMPLE_LOCATIONS will always return TRUE if the mechanism is
	explicitly used to set the sample positions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/sample_positions.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.sample_positions import *
from OpenGL.raw.GL.AMD.sample_positions import _EXTENSION_NAME

def glInitSamplePositionsAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glSetMultisamplefvAMD=wrapper.wrapper(glSetMultisamplefvAMD).setInputArraySize(
    'val', 2
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.fragment_lighting

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.fragment_lighting to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/fragment_lighting.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.fragment_lighting import *
from OpenGL.raw.GL.SGIX.fragment_lighting import _EXTENSION_NAME

def glInitFragmentLightingSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glFragmentLightfvSGIX.params size not checked against 'pname'
glFragmentLightfvSGIX=wrapper.wrapper(glFragmentLightfvSGIX).setInputArraySize(
    'params', None
)
# INPUT glFragmentLightivSGIX.params size not checked against 'pname'
glFragmentLightivSGIX=wrapper.wrapper(glFragmentLightivSGIX).setInputArraySize(
    'params', None
)
# INPUT glFragmentLightModelfvSGIX.params size not checked against 'pname'
glFragmentLightModelfvSGIX=wrapper.wrapper(glFragmentLightModelfvSGIX).setInputArraySize(
    'params', None
)
# INPUT glFragmentLightModelivSGIX.params size not checked against 'pname'
glFragmentLightModelivSGIX=wrapper.wrapper(glFragmentLightModelivSGIX).setInputArraySize(
    'params', None
)
# INPUT glFragmentMaterialfvSGIX.params size not checked against 'pname'
glFragmentMaterialfvSGIX=wrapper.wrapper(glFragmentMaterialfvSGIX).setInputArraySize(
    'params', None
)
# INPUT glFragmentMaterialivSGIX.params size not checked against 'pname'
glFragmentMaterialivSGIX=wrapper.wrapper(glFragmentMaterialivSGIX).setInputArraySize(
    'params', None
)
glGetFragmentLightfvSGIX=wrapper.wrapper(glGetFragmentLightfvSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFragmentLightivSGIX=wrapper.wrapper(glGetFragmentLightivSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFragmentMaterialfvSGIX=wrapper.wrapper(glGetFragmentMaterialfvSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFragmentMaterialivSGIX=wrapper.wrapper(glGetFragmentMaterialivSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_vertex_type_2_10_10_10_rev'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_vertex_type_2_10_10_10_rev',error_checker=_errors._error_checker)
GL_INT_2_10_10_10_REV=_C('GL_INT_2_10_10_10_REV',0x8D9F)
GL_UNSIGNED_INT_2_10_10_10_REV=_C('GL_UNSIGNED_INT_2_10_10_10_REV',0x8368)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glColorP3ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glColorP3uiv(type,color):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glColorP4ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glColorP4uiv(type,color):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP1ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP1uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP2ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP2uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP3ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP3uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glMultiTexCoordP4ui(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLuintArray)
def glMultiTexCoordP4uiv(texture,type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glNormalP3ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glNormalP3uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glSecondaryColorP3ui(type,color):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glSecondaryColorP3uiv(type,color):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP1ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP1uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP2ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP2uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP3ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP3uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glTexCoordP4ui(type,coords):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glTexCoordP4uiv(type,coords):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP1ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP1uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP2ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP2uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP3ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP3uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,_cs.GLuint)
def glVertexAttribP4ui(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLboolean,arrays.GLuintArray)
def glVertexAttribP4uiv(index,type,normalized,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP2ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP2uiv(type,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP3ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP3uiv(type,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glVertexP4ui(type,value):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glVertexP4uiv(type,value):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_texture_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_texture_buffer',error_checker=_errors._error_checker)
GL_IMAGE_BUFFER_OES=_C('GL_IMAGE_BUFFER_OES',0x9051)
GL_INT_IMAGE_BUFFER_OES=_C('GL_INT_IMAGE_BUFFER_OES',0x905C)
GL_INT_SAMPLER_BUFFER_OES=_C('GL_INT_SAMPLER_BUFFER_OES',0x8DD0)
GL_MAX_TEXTURE_BUFFER_SIZE_OES=_C('GL_MAX_TEXTURE_BUFFER_SIZE_OES',0x8C2B)
GL_SAMPLER_BUFFER_OES=_C('GL_SAMPLER_BUFFER_OES',0x8DC2)
GL_TEXTURE_BINDING_BUFFER_OES=_C('GL_TEXTURE_BINDING_BUFFER_OES',0x8C2C)
GL_TEXTURE_BUFFER_BINDING_OES=_C('GL_TEXTURE_BUFFER_BINDING_OES',0x8C2A)
GL_TEXTURE_BUFFER_DATA_STORE_BINDING_OES=_C('GL_TEXTURE_BUFFER_DATA_STORE_BINDING_OES',0x8C2D)
GL_TEXTURE_BUFFER_OES=_C('GL_TEXTURE_BUFFER_OES',0x8C2A)
GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_OES=_C('GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT_OES',0x919F)
GL_TEXTURE_BUFFER_OFFSET_OES=_C('GL_TEXTURE_BUFFER_OFFSET_OES',0x919D)
GL_TEXTURE_BUFFER_SIZE_OES=_C('GL_TEXTURE_BUFFER_SIZE_OES',0x919E)
GL_UNSIGNED_INT_IMAGE_BUFFER_OES=_C('GL_UNSIGNED_INT_IMAGE_BUFFER_OES',0x9067)
GL_UNSIGNED_INT_SAMPLER_BUFFER_OES=_C('GL_UNSIGNED_INT_SAMPLER_BUFFER_OES',0x8DD8)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glTexBufferOES(target,internalformat,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glTexBufferRangeOES(target,internalformat,buffer,offset,size):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_multi_draw_arrays'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_multi_draw_arrays',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray,arrays.GLsizeiArray,_cs.GLsizei)
def glMultiDrawArraysEXT(mode,first,count,primcount):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLsizeiArray,_cs.GLenum,arrays.GLvoidpArray,_cs.GLsizei)
def glMultiDrawElementsEXT(mode,count,type,indices,primcount):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_perturb_normal'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_perturb_normal',error_checker=_errors._error_checker)
GL_PERTURB_EXT=_C('GL_PERTURB_EXT',0x85AE)
GL_TEXTURE_NORMAL_EXT=_C('GL_TEXTURE_NORMAL_EXT',0x85AF)
@_f
@_p.types(None,_cs.GLenum)
def glTextureNormalEXT(mode):pass



'''OpenGL extension ARB.shader_precision

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_precision to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension more clearly restricts the precision requirements of 
	implementations of the GLSL specification.  These include precision of 
	arithmetic operations (operators '+', '/', ...), transcendentals (log, exp, 
	pow, reciprocal sqrt, ...), when NaNs (not a number) and INFs (infinities) will
	be supported and generated, and denorm flushing behavior.  Trigonometric 
	built-ins and some other categories of built-ins are not addressed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_precision.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_precision import *
from OpenGL.raw.GL.ARB.shader_precision import _EXTENSION_NAME

def glInitShaderPrecisionARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_tessellation_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_tessellation_shader',error_checker=_errors._error_checker)
GL_CCW=_C('GL_CCW',0x0901)
GL_CW=_C('GL_CW',0x0900)
GL_EQUAL=_C('GL_EQUAL',0x0202)
GL_FRACTIONAL_EVEN_EXT=_C('GL_FRACTIONAL_EVEN_EXT',0x8E7C)
GL_FRACTIONAL_ODD_EXT=_C('GL_FRACTIONAL_ODD_EXT',0x8E7B)
GL_ISOLINES_EXT=_C('GL_ISOLINES_EXT',0x8E7A)
GL_IS_PER_PATCH_EXT=_C('GL_IS_PER_PATCH_EXT',0x92E7)
GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_EXT=_C('GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS_EXT',0x8E1E)
GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT=_C('GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT',0x8E1F)
GL_MAX_PATCH_VERTICES_EXT=_C('GL_MAX_PATCH_VERTICES_EXT',0x8E7D)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_EXT=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS_EXT',0x92D3)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_EXT=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS_EXT',0x92CD)
GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_EXT=_C('GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS_EXT',0x90CB)
GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_EXT=_C('GL_MAX_TESS_CONTROL_INPUT_COMPONENTS_EXT',0x886C)
GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_EXT=_C('GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS_EXT',0x8E83)
GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_EXT=_C('GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS_EXT',0x90D8)
GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_EXT=_C('GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS_EXT',0x8E81)
GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_EXT=_C('GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS_EXT',0x8E85)
GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_EXT=_C('GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS_EXT',0x8E89)
GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_EXT=_C('GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS_EXT',0x8E7F)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_EXT=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS_EXT',0x92D4)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_EXT=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS_EXT',0x92CE)
GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_EXT=_C('GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS_EXT',0x90CC)
GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_EXT=_C('GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS_EXT',0x886D)
GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_EXT=_C('GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS_EXT',0x8E86)
GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_EXT=_C('GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS_EXT',0x90D9)
GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_EXT=_C('GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS_EXT',0x8E82)
GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_EXT=_C('GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS_EXT',0x8E8A)
GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT=_C('GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS_EXT',0x8E80)
GL_MAX_TESS_GEN_LEVEL_EXT=_C('GL_MAX_TESS_GEN_LEVEL_EXT',0x8E7E)
GL_MAX_TESS_PATCH_COMPONENTS_EXT=_C('GL_MAX_TESS_PATCH_COMPONENTS_EXT',0x8E84)
GL_PATCHES_EXT=_C('GL_PATCHES_EXT',0x000E)
GL_PATCH_VERTICES_EXT=_C('GL_PATCH_VERTICES_EXT',0x8E72)
GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED=_C('GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED',0x8221)
GL_QUADS_EXT=_C('GL_QUADS_EXT',0x0007)
GL_REFERENCED_BY_TESS_CONTROL_SHADER_EXT=_C('GL_REFERENCED_BY_TESS_CONTROL_SHADER_EXT',0x9307)
GL_REFERENCED_BY_TESS_EVALUATION_SHADER_EXT=_C('GL_REFERENCED_BY_TESS_EVALUATION_SHADER_EXT',0x9308)
GL_TESS_CONTROL_OUTPUT_VERTICES_EXT=_C('GL_TESS_CONTROL_OUTPUT_VERTICES_EXT',0x8E75)
GL_TESS_CONTROL_SHADER_BIT_EXT=_C('GL_TESS_CONTROL_SHADER_BIT_EXT',0x00000008)
GL_TESS_CONTROL_SHADER_EXT=_C('GL_TESS_CONTROL_SHADER_EXT',0x8E88)
GL_TESS_EVALUATION_SHADER_BIT_EXT=_C('GL_TESS_EVALUATION_SHADER_BIT_EXT',0x00000010)
GL_TESS_EVALUATION_SHADER_EXT=_C('GL_TESS_EVALUATION_SHADER_EXT',0x8E87)
GL_TESS_GEN_MODE_EXT=_C('GL_TESS_GEN_MODE_EXT',0x8E76)
GL_TESS_GEN_POINT_MODE_EXT=_C('GL_TESS_GEN_POINT_MODE_EXT',0x8E79)
GL_TESS_GEN_SPACING_EXT=_C('GL_TESS_GEN_SPACING_EXT',0x8E77)
GL_TESS_GEN_VERTEX_ORDER_EXT=_C('GL_TESS_GEN_VERTEX_ORDER_EXT',0x8E78)
GL_TRIANGLES=_C('GL_TRIANGLES',0x0004)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPatchParameteriEXT(pname,value):pass



'''OpenGL extension ARB.direct_state_access

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.direct_state_access to provide a more 
Python-friendly API

Overview (from the spec)
	
	In unextended OpenGL, most mutation of state contained in objects is through
	an indirection known as a binding. Objects are attached to a context (either
	directly or indirectly via a container) and then commands to modify or
	query their state are issued on that context, indirecting through its
	attachments and into the underlying object. This is known as `bind-to-edit'.
	
	This extension derives from the GL_EXT_direct_state_access extension, which
	added accessors for most state on most objects, allowing it to be queried
	and modified without the object needing to be bound to a context. In cases
	where a single property of an object is to be modified, directly accessing
	its state can be more efficient than binding the object to the context and
	then indirecting through it. Further, directly accessing the state of
	objects through their names rather than by bind-to-edit does not disturb
	the bindings of the current context, which is useful for tools, middleware
	and other applications that are unaware of the outer state but it can also
	avoid cases of redundant state changes.
	
	There are several subtle differences between this extension and the older
	GL_EXT_direct_state_access extension. First, this extension only expands
	functionality that still exists in core profile OpenGL. Second, any function
	that only partially avoids bind-to-edit (for example, explicitly specifying
	a texture unit, bypassing the active texture selector but still indirecting
	through a texture binding) has been omitted. Finally, the original extension
	effectively allowed any function to create new objects whereas in unextended
	OpenGL, only binding functions created objects (bind-to-create), even if
	their names were obtained through one of the glGen* functions. This
	extension does not allow on-the-spot creation of objects. Rather than rely
	on bind-to-create (which would defeat the purpose of the extension), we add
	glCreate* functions that produce new names that represent state vectors
	initialized to their default values. Due to this last change, several
	functions no longer require their <target> parameters, and so where
	applicable, this parameter is absent from this extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/direct_state_access.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.direct_state_access import *
from OpenGL.raw.GL.ARB.direct_state_access import _EXTENSION_NAME

def glInitDirectStateAccessARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_storage_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_storage_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	The ARB_texture_storage extension and OpenGL 4.2 introduced the concept
	of immutable texture objects. With these objects, once their data store
	has been sized and allocated, it could not be resized for the lifetime
	of the objects (although its content could be updated). OpenGL
	implementations may be able to take advantage of the knowledge that the
	underlying data store of certain objects cannot be deleted or otherwise
	reallocated without destruction of the whole object (normally, a much
	heavier weight and less frequent operation). Immutable storage
	for all types of textures besides multisample and buffer textures was
	introduced by ARB_texture_storage. For completeness, this extension
	introduces immutable storage for multisampled textures.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_storage_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_storage_multisample import *
from OpenGL.raw.GL.ARB.texture_storage_multisample import _EXTENSION_NAME

def glInitTextureStorageMultisampleARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_sRGB'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_sRGB',error_checker=_errors._error_checker)
GL_COMPRESSED_SLUMINANCE_ALPHA_EXT=_C('GL_COMPRESSED_SLUMINANCE_ALPHA_EXT',0x8C4B)
GL_COMPRESSED_SLUMINANCE_EXT=_C('GL_COMPRESSED_SLUMINANCE_EXT',0x8C4A)
GL_COMPRESSED_SRGB_ALPHA_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_EXT',0x8C49)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_EXT',0x8C4D)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_EXT',0x8C4E)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_EXT',0x8C4F)
GL_COMPRESSED_SRGB_EXT=_C('GL_COMPRESSED_SRGB_EXT',0x8C48)
GL_COMPRESSED_SRGB_S3TC_DXT1_EXT=_C('GL_COMPRESSED_SRGB_S3TC_DXT1_EXT',0x8C4C)
GL_SLUMINANCE8_ALPHA8_EXT=_C('GL_SLUMINANCE8_ALPHA8_EXT',0x8C45)
GL_SLUMINANCE8_EXT=_C('GL_SLUMINANCE8_EXT',0x8C47)
GL_SLUMINANCE_ALPHA_EXT=_C('GL_SLUMINANCE_ALPHA_EXT',0x8C44)
GL_SLUMINANCE_EXT=_C('GL_SLUMINANCE_EXT',0x8C46)
GL_SRGB8_ALPHA8_EXT=_C('GL_SRGB8_ALPHA8_EXT',0x8C43)
GL_SRGB8_EXT=_C('GL_SRGB8_EXT',0x8C41)
GL_SRGB_ALPHA_EXT=_C('GL_SRGB_ALPHA_EXT',0x8C42)
GL_SRGB_EXT=_C('GL_SRGB_EXT',0x8C40)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_gpu_shader4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_gpu_shader4',error_checker=_errors._error_checker)
GL_INT_SAMPLER_1D_ARRAY_EXT=_C('GL_INT_SAMPLER_1D_ARRAY_EXT',0x8DCE)
GL_INT_SAMPLER_1D_EXT=_C('GL_INT_SAMPLER_1D_EXT',0x8DC9)
GL_INT_SAMPLER_2D_ARRAY_EXT=_C('GL_INT_SAMPLER_2D_ARRAY_EXT',0x8DCF)
GL_INT_SAMPLER_2D_EXT=_C('GL_INT_SAMPLER_2D_EXT',0x8DCA)
GL_INT_SAMPLER_2D_RECT_EXT=_C('GL_INT_SAMPLER_2D_RECT_EXT',0x8DCD)
GL_INT_SAMPLER_3D_EXT=_C('GL_INT_SAMPLER_3D_EXT',0x8DCB)
GL_INT_SAMPLER_BUFFER_EXT=_C('GL_INT_SAMPLER_BUFFER_EXT',0x8DD0)
GL_INT_SAMPLER_CUBE_EXT=_C('GL_INT_SAMPLER_CUBE_EXT',0x8DCC)
GL_MAX_PROGRAM_TEXEL_OFFSET_EXT=_C('GL_MAX_PROGRAM_TEXEL_OFFSET_EXT',0x8905)
GL_MIN_PROGRAM_TEXEL_OFFSET_EXT=_C('GL_MIN_PROGRAM_TEXEL_OFFSET_EXT',0x8904)
GL_SAMPLER_1D_ARRAY_EXT=_C('GL_SAMPLER_1D_ARRAY_EXT',0x8DC0)
GL_SAMPLER_1D_ARRAY_SHADOW_EXT=_C('GL_SAMPLER_1D_ARRAY_SHADOW_EXT',0x8DC3)
GL_SAMPLER_2D_ARRAY_EXT=_C('GL_SAMPLER_2D_ARRAY_EXT',0x8DC1)
GL_SAMPLER_2D_ARRAY_SHADOW_EXT=_C('GL_SAMPLER_2D_ARRAY_SHADOW_EXT',0x8DC4)
GL_SAMPLER_BUFFER_EXT=_C('GL_SAMPLER_BUFFER_EXT',0x8DC2)
GL_SAMPLER_CUBE_SHADOW_EXT=_C('GL_SAMPLER_CUBE_SHADOW_EXT',0x8DC5)
GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT=_C('GL_UNSIGNED_INT_SAMPLER_1D_ARRAY_EXT',0x8DD6)
GL_UNSIGNED_INT_SAMPLER_1D_EXT=_C('GL_UNSIGNED_INT_SAMPLER_1D_EXT',0x8DD1)
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT=_C('GL_UNSIGNED_INT_SAMPLER_2D_ARRAY_EXT',0x8DD7)
GL_UNSIGNED_INT_SAMPLER_2D_EXT=_C('GL_UNSIGNED_INT_SAMPLER_2D_EXT',0x8DD2)
GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT=_C('GL_UNSIGNED_INT_SAMPLER_2D_RECT_EXT',0x8DD5)
GL_UNSIGNED_INT_SAMPLER_3D_EXT=_C('GL_UNSIGNED_INT_SAMPLER_3D_EXT',0x8DD3)
GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT=_C('GL_UNSIGNED_INT_SAMPLER_BUFFER_EXT',0x8DD8)
GL_UNSIGNED_INT_SAMPLER_CUBE_EXT=_C('GL_UNSIGNED_INT_SAMPLER_CUBE_EXT',0x8DD4)
GL_UNSIGNED_INT_VEC2_EXT=_C('GL_UNSIGNED_INT_VEC2_EXT',0x8DC6)
GL_UNSIGNED_INT_VEC3_EXT=_C('GL_UNSIGNED_INT_VEC3_EXT',0x8DC7)
GL_UNSIGNED_INT_VEC4_EXT=_C('GL_UNSIGNED_INT_VEC4_EXT',0x8DC8)
GL_VERTEX_ATTRIB_ARRAY_INTEGER_EXT=_C('GL_VERTEX_ATTRIB_ARRAY_INTEGER_EXT',0x88FD)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glBindFragDataLocationEXT(program,color,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetFragDataLocationEXT(program,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,arrays.GLuintArray)
def glGetUniformuivEXT(program,location,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint)
def glUniform1uiEXT(location,v0):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform1uivEXT(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint)
def glUniform2uiEXT(location,v0,v1):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform2uivEXT(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform3uiEXT(location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform3uivEXT(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform4uiEXT(location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform4uivEXT(location,count,value):pass



'''OpenGL extension ARB.shading_language_include

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shading_language_include to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a #include GLSL directive to allow reusing
	the same shader text in multiple shaders and defines the semantics
	and syntax of the names allowed in #include directives. It also
	defines API mechanisms to define the named string backing a
	#include.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shading_language_include.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shading_language_include import *
from OpenGL.raw.GL.ARB.shading_language_include import _EXTENSION_NAME

def glInitShadingLanguageIncludeARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glNamedStringARB.name size not checked against namelen
# INPUT glNamedStringARB.string size not checked against stringlen
glNamedStringARB=wrapper.wrapper(glNamedStringARB).setInputArraySize(
    'name', None
).setInputArraySize(
    'string', None
)
# INPUT glDeleteNamedStringARB.name size not checked against namelen
glDeleteNamedStringARB=wrapper.wrapper(glDeleteNamedStringARB).setInputArraySize(
    'name', None
)
# INPUT glCompileShaderIncludeARB.length size not checked against count
# INPUT glCompileShaderIncludeARB.path size not checked against count
glCompileShaderIncludeARB=wrapper.wrapper(glCompileShaderIncludeARB).setInputArraySize(
    'length', None
).setInputArraySize(
    'path', None
)
# INPUT glIsNamedStringARB.name size not checked against namelen
glIsNamedStringARB=wrapper.wrapper(glIsNamedStringARB).setInputArraySize(
    'name', None
)
# INPUT glGetNamedStringARB.name size not checked against namelen
glGetNamedStringARB=wrapper.wrapper(glGetNamedStringARB).setInputArraySize(
    'name', None
).setOutput(
    'string',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'stringlen',size=(1,),orPassIn=True
)
# INPUT glGetNamedStringivARB.name size not checked against namelen
glGetNamedStringivARB=wrapper.wrapper(glGetNamedStringivARB).setInputArraySize(
    'name', None
).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.list_priority

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.list_priority to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for specifying the relative
	importance of display lists.  This information can be used by
	an OpenGL implementation to guide the placement of display
	list data in a storage hierarchy.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/list_priority.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.list_priority import *
from OpenGL.raw.GL.SGIX.list_priority import _EXTENSION_NAME

def glInitListPrioritySGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetListParameterfvSGIX=wrapper.wrapper(glGetListParameterfvSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetListParameterivSGIX=wrapper.wrapper(glGetListParameterivSGIX).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glListParameterfvSGIX.params size not checked against 'pname'
glListParameterfvSGIX=wrapper.wrapper(glListParameterfvSGIX).setInputArraySize(
    'params', None
)
# INPUT glListParameterivSGIX.params size not checked against 'pname'
glListParameterivSGIX=wrapper.wrapper(glListParameterivSGIX).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_texture_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_texture_shader',error_checker=_errors._error_checker)
GL_CONST_EYE_NV=_C('GL_CONST_EYE_NV',0x86E5)
GL_CULL_FRAGMENT_NV=_C('GL_CULL_FRAGMENT_NV',0x86E7)
GL_CULL_MODES_NV=_C('GL_CULL_MODES_NV',0x86E0)
GL_DEPENDENT_AR_TEXTURE_2D_NV=_C('GL_DEPENDENT_AR_TEXTURE_2D_NV',0x86E9)
GL_DEPENDENT_GB_TEXTURE_2D_NV=_C('GL_DEPENDENT_GB_TEXTURE_2D_NV',0x86EA)
GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV',0x86F3)
GL_DOT_PRODUCT_DEPTH_REPLACE_NV=_C('GL_DOT_PRODUCT_DEPTH_REPLACE_NV',0x86ED)
GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV',0x86F1)
GL_DOT_PRODUCT_NV=_C('GL_DOT_PRODUCT_NV',0x86EC)
GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV',0x86F2)
GL_DOT_PRODUCT_TEXTURE_2D_NV=_C('GL_DOT_PRODUCT_TEXTURE_2D_NV',0x86EE)
GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV=_C('GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV',0x86F0)
GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV=_C('GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV',0x864E)
GL_DSDT8_MAG8_INTENSITY8_NV=_C('GL_DSDT8_MAG8_INTENSITY8_NV',0x870B)
GL_DSDT8_MAG8_NV=_C('GL_DSDT8_MAG8_NV',0x870A)
GL_DSDT8_NV=_C('GL_DSDT8_NV',0x8709)
GL_DSDT_MAG_INTENSITY_NV=_C('GL_DSDT_MAG_INTENSITY_NV',0x86DC)
GL_DSDT_MAG_NV=_C('GL_DSDT_MAG_NV',0x86F6)
GL_DSDT_MAG_VIB_NV=_C('GL_DSDT_MAG_VIB_NV',0x86F7)
GL_DSDT_NV=_C('GL_DSDT_NV',0x86F5)
GL_DS_BIAS_NV=_C('GL_DS_BIAS_NV',0x8716)
GL_DS_SCALE_NV=_C('GL_DS_SCALE_NV',0x8710)
GL_DT_BIAS_NV=_C('GL_DT_BIAS_NV',0x8717)
GL_DT_SCALE_NV=_C('GL_DT_SCALE_NV',0x8711)
GL_HILO16_NV=_C('GL_HILO16_NV',0x86F8)
GL_HILO_NV=_C('GL_HILO_NV',0x86F4)
GL_HI_BIAS_NV=_C('GL_HI_BIAS_NV',0x8714)
GL_HI_SCALE_NV=_C('GL_HI_SCALE_NV',0x870E)
GL_LO_BIAS_NV=_C('GL_LO_BIAS_NV',0x8715)
GL_LO_SCALE_NV=_C('GL_LO_SCALE_NV',0x870F)
GL_MAGNITUDE_BIAS_NV=_C('GL_MAGNITUDE_BIAS_NV',0x8718)
GL_MAGNITUDE_SCALE_NV=_C('GL_MAGNITUDE_SCALE_NV',0x8712)
GL_OFFSET_TEXTURE_2D_BIAS_NV=_C('GL_OFFSET_TEXTURE_2D_BIAS_NV',0x86E3)
GL_OFFSET_TEXTURE_2D_MATRIX_NV=_C('GL_OFFSET_TEXTURE_2D_MATRIX_NV',0x86E1)
GL_OFFSET_TEXTURE_2D_NV=_C('GL_OFFSET_TEXTURE_2D_NV',0x86E8)
GL_OFFSET_TEXTURE_2D_SCALE_NV=_C('GL_OFFSET_TEXTURE_2D_SCALE_NV',0x86E2)
GL_OFFSET_TEXTURE_BIAS_NV=_C('GL_OFFSET_TEXTURE_BIAS_NV',0x86E3)
GL_OFFSET_TEXTURE_MATRIX_NV=_C('GL_OFFSET_TEXTURE_MATRIX_NV',0x86E1)
GL_OFFSET_TEXTURE_RECTANGLE_NV=_C('GL_OFFSET_TEXTURE_RECTANGLE_NV',0x864C)
GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV=_C('GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV',0x864D)
GL_OFFSET_TEXTURE_SCALE_NV=_C('GL_OFFSET_TEXTURE_SCALE_NV',0x86E2)
GL_PASS_THROUGH_NV=_C('GL_PASS_THROUGH_NV',0x86E6)
GL_PREVIOUS_TEXTURE_INPUT_NV=_C('GL_PREVIOUS_TEXTURE_INPUT_NV',0x86E4)
GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV=_C('GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV',0x86D9)
GL_SHADER_CONSISTENT_NV=_C('GL_SHADER_CONSISTENT_NV',0x86DD)
GL_SHADER_OPERATION_NV=_C('GL_SHADER_OPERATION_NV',0x86DF)
GL_SIGNED_ALPHA8_NV=_C('GL_SIGNED_ALPHA8_NV',0x8706)
GL_SIGNED_ALPHA_NV=_C('GL_SIGNED_ALPHA_NV',0x8705)
GL_SIGNED_HILO16_NV=_C('GL_SIGNED_HILO16_NV',0x86FA)
GL_SIGNED_HILO_NV=_C('GL_SIGNED_HILO_NV',0x86F9)
GL_SIGNED_INTENSITY8_NV=_C('GL_SIGNED_INTENSITY8_NV',0x8708)
GL_SIGNED_INTENSITY_NV=_C('GL_SIGNED_INTENSITY_NV',0x8707)
GL_SIGNED_LUMINANCE8_ALPHA8_NV=_C('GL_SIGNED_LUMINANCE8_ALPHA8_NV',0x8704)
GL_SIGNED_LUMINANCE8_NV=_C('GL_SIGNED_LUMINANCE8_NV',0x8702)
GL_SIGNED_LUMINANCE_ALPHA_NV=_C('GL_SIGNED_LUMINANCE_ALPHA_NV',0x8703)
GL_SIGNED_LUMINANCE_NV=_C('GL_SIGNED_LUMINANCE_NV',0x8701)
GL_SIGNED_RGB8_NV=_C('GL_SIGNED_RGB8_NV',0x86FF)
GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV=_C('GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV',0x870D)
GL_SIGNED_RGBA8_NV=_C('GL_SIGNED_RGBA8_NV',0x86FC)
GL_SIGNED_RGBA_NV=_C('GL_SIGNED_RGBA_NV',0x86FB)
GL_SIGNED_RGB_NV=_C('GL_SIGNED_RGB_NV',0x86FE)
GL_SIGNED_RGB_UNSIGNED_ALPHA_NV=_C('GL_SIGNED_RGB_UNSIGNED_ALPHA_NV',0x870C)
GL_TEXTURE_BORDER_VALUES_NV=_C('GL_TEXTURE_BORDER_VALUES_NV',0x871A)
GL_TEXTURE_DS_SIZE_NV=_C('GL_TEXTURE_DS_SIZE_NV',0x871D)
GL_TEXTURE_DT_SIZE_NV=_C('GL_TEXTURE_DT_SIZE_NV',0x871E)
GL_TEXTURE_HI_SIZE_NV=_C('GL_TEXTURE_HI_SIZE_NV',0x871B)
GL_TEXTURE_LO_SIZE_NV=_C('GL_TEXTURE_LO_SIZE_NV',0x871C)
GL_TEXTURE_MAG_SIZE_NV=_C('GL_TEXTURE_MAG_SIZE_NV',0x871F)
GL_TEXTURE_SHADER_NV=_C('GL_TEXTURE_SHADER_NV',0x86DE)
GL_UNSIGNED_INT_8_8_S8_S8_REV_NV=_C('GL_UNSIGNED_INT_8_8_S8_S8_REV_NV',0x86DB)
GL_UNSIGNED_INT_S8_S8_8_8_NV=_C('GL_UNSIGNED_INT_S8_S8_8_8_NV',0x86DA)
GL_VIBRANCE_BIAS_NV=_C('GL_VIBRANCE_BIAS_NV',0x8719)
GL_VIBRANCE_SCALE_NV=_C('GL_VIBRANCE_SCALE_NV',0x8713)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_compiled_vertex_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_compiled_vertex_array',error_checker=_errors._error_checker)
GL_ARRAY_ELEMENT_LOCK_COUNT_EXT=_C('GL_ARRAY_ELEMENT_LOCK_COUNT_EXT',0x81A9)
GL_ARRAY_ELEMENT_LOCK_FIRST_EXT=_C('GL_ARRAY_ELEMENT_LOCK_FIRST_EXT',0x81A8)
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei)
def glLockArraysEXT(first,count):pass
@_f
@_p.types(None,)
def glUnlockArraysEXT():pass



'''OpenGL extension SGI.make_current_read

This module customises the behaviour of the 
OpenGL.raw.GLX.SGI.make_current_read to provide a more 
Python-friendly API

Overview (from the spec)
	
	The association of the current context with a drawable is extended to allow
	separate write and read drawables.  This paves the way for allowing
	preprocessing of image data in an "off screen" window which is then read
	into the visible window for final display.  Similarly it sets the
	frame-work for direct transfer of video to the GL, by treating the video
	as a special kind of read drawable (a.k.a, readable).
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGI/make_current_read.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGI.make_current_read import *
from OpenGL.raw.GLX.SGI.make_current_read import _EXTENSION_NAME

def glInitMakeCurrentReadSGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ATI.vertex_array_object

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.vertex_array_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines an interface that allows multiple sets of
	vertex array data to be cached in persistent server-side memory.
	It is intended to allow client data to be stored in memory that
	can be directly accessed by graphics hardware.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/vertex_array_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.vertex_array_object import *
from OpenGL.raw.GL.ATI.vertex_array_object import _EXTENSION_NAME

def glInitVertexArrayObjectATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glNewObjectBufferATI.pointer size not checked against size
glNewObjectBufferATI=wrapper.wrapper(glNewObjectBufferATI).setInputArraySize(
    'pointer', None
)
# INPUT glUpdateObjectBufferATI.pointer size not checked against size
glUpdateObjectBufferATI=wrapper.wrapper(glUpdateObjectBufferATI).setInputArraySize(
    'pointer', None
)
glGetObjectBufferfvATI=wrapper.wrapper(glGetObjectBufferfvATI).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetObjectBufferivATI=wrapper.wrapper(glGetObjectBufferivATI).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetArrayObjectfvATI=wrapper.wrapper(glGetArrayObjectfvATI).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetArrayObjectivATI=wrapper.wrapper(glGetArrayObjectivATI).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetVariantArrayObjectfvATI=wrapper.wrapper(glGetVariantArrayObjectfvATI).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetVariantArrayObjectivATI=wrapper.wrapper(glGetVariantArrayObjectivATI).setOutput(
    'params',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.texture_lod

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.texture_lod to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension imposes two constraints related to the texture level of
	detail parameter LOD, which is represented by the Greek character lambda
	in the GL Specification.  One constraint clamps LOD to a specified
	floating point range.  The other limits the selection of mipmap image
	arrays to a subset of the arrays that would otherwise be considered.
	
	Together these constraints allow a large texture to be loaded and
	used initially at low resolution, and to have its resolution raised
	gradually as more resolution is desired or available.  Image array
	specification is necessarily integral, rather than continuous.  By
	providing separate, continuous clamping of the LOD parameter, it is
	possible to avoid "popping" artifacts when higher resolution images
	are provided.
	
	Note: because the shape of the mipmap array is always determined by
	the dimensions of the level 0 array, this array must be loaded for
	mipmapping to be active.  If the level 0 array is specified with a
	null image pointer, however, no actual data transfer will take
	place.  And a sufficiently tuned implementation might not even
	allocate space for a level 0 array so specified until true image
	data were presented.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/texture_lod.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.texture_lod import *
from OpenGL.raw.GL.SGIS.texture_lod import _EXTENSION_NAME

def glInitTextureLodSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION